require 'pathname'

Given(/^I have a valid project$/) do
  @root = Pathname.new('tmp/data')
  @root.mkpath
  @required_paths = %w[drafts posts formats].map{|p| @root + p}
  @required_paths.each{|p| p.mkpath}
end

Given(/^I have a (\w+?) format$/) do |format_name|
  create_format "#{format_name}", @root + 'formats'
end

Given(/^I have a completed draft$/) do
  @post_name = 'testing-testing.md'
  create_test_draft @post_name, (@root + 'drafts')
end

When(/^I run contraption$/) do
  @output = @root + '..' + 'output'
  `ruby -Ilib bin/contraption -s #{@root} -d #{@output}`
end

Then(/^I should have a new post$/) do
  @post_path = @root + 'posts' + "#{Date.today.strftime('%Y%m%d-')+@post_name}"
  File.exist?(@post_path).should be_true
end

Then(/^The draft should be removed$/) do
  File.exist?(@root + 'drafts' + @post_name).should be_false
end

Then(/^The post should be the formatted version of the draft$/) do
  post_content = File.read(@post_path)
  post_content.should_not include('Contraption::Post')
  post_content.should_not include('Published: now')
end

Given(/^The project has a post titled "(.*)" from (\d+) (\S+) (\d+) tagged (\S+)$/) do |title, day, month, year, tags|
  publication = "#{day} #{month} #{year}"
  p = create_post_with published: publication, title: title, tags: tags
  save_post p, @root + 'posts'
end

Then(/^The site should contain (.*)$/) do |path|
  File.exist?(@output + path).should be_true
end

Then(/^'(.*?)' should have "(.*?)" before "(.*?)"\.$/) do |path, first_string, second_string|
  content = File.read(@output+path)
  content.index(first_string).should < content.index(second_string)
end
