require_relative '../../lib/contraption/header'
require_relative '../../lib/contraption/post'

def create_test_draft name, path
  content =<<-POST
Testing... Testing...
Type: Article
Tags: Test
Summary: Testing.
Published: now

Testing whether the markdown support works.

Code sample
    #include<iostream>

    int main(){
    std::cout << "Hello World.\\n";
    return 0;
    }

Some __bold text__.

And an image for good luck ![test](test2.jpg)
  POST
  write_file content, path+name
end

def create_post_with opts={}

end

def create_format name="raw", path
  format = case name
  when /article/
    article_format
  when /landing_page/
    landing_page_format
  when /page/
    page_format
  when /month/
    month_format
  when /year/
    year_format
  when /tag_cloud/
    tag_cloud_format
  when /tag/
    tag_format
  else
    raw_format
  end
  write_file format, path+"#{name}.erb"
end

def raw_format
  <<-'FORMAT'
<%=context.title%>
Type: <%=context.type%>
Tags: <%=context.tags%>
Published: <%=context.publication_date%>
Summary: <%=context.summary%>

<%=context.body%>
  FORMAT
end

def month_format
  <<-'FORMAT'
<h1 class=\"archive\">ARCHIVE FOR '#{context[:month].month} #{context[:month].year}'</h1>\n<hr class=\"subtleSep\" />
<%= context[:content] %>

  FORMAT
end

def year_format
  <<-'FORMAT'
<h1 class=\"archive\">ARCHIVE FOR '#{context[:year].year}'</h1>\n<hr class=\"subtleSep\" />
<%= context[:content] %>

  FORMAT
end

def tag_format
  <<-'FORMAT'
<h1 class-\"archive\"ARCHIVE FOR '#{context[:tag]}'</h1><\n<hr class=\"subtleSep\" />
<%= context[:content] %>
  FORMAT
end

def tag_cloud_format
  <<-'FORMAT'
<%= context[:content] %>
  FORMAT
end

def article_format
  <<-'FORMAT'
<article class="group">
  <div class="grid14 thetitle">
    <h1><%= context.title %></h1>
  </div>
  <div class="metadata grid2">
    <span class="date">
      <%= context.publication_date.strftime("%-d %b %Y")%>
    </span>
    <% context.tags.each do |t| %>
      <span class="tag">
        <a href="/tags/<%= t.to_s.gsub ' ', '_' %>">
          <%= t.to_s %>
        </a>
      </span>
    <% end %>
  </div>
  <div class="grid14">
    <%= context.body %>
  </div>
</article>
  FORMAT
end

def page_format
  <<-'FORMAT'
<!doctype html>
<body>
  <section class="sidebar">
  </section>
  <section class="content">
  <%= context %>
  </section>
</body>
  FORMAT
end

def landing_page_format
  <<-'FORMAT'
  <!doctype html>
  <body class="land">
  <section class="banner">
  <img src="logo.png" />
  <nav>
    <ul>
      <li><a href="recent.html">Posts</a></li>
      <li><a href="projects.html">Projects</a></li>
    </ul>
  </nav>
  </section>
  <%= context[:most_recent].title %>
  </body>
  </html>
  FORMAT
end

def default_post_params
  {
   title:     random_string,
   type:      "Article",
   tags:      "Test, demo",
   summary:   "Teaser",
   published: "now",
   content:   "Some repeated content.\n\n"*10
  }
end

def create_post_with options={}
  opts = default_post_params.merge(options)
  s = []
  s << opts.fetch(:title)
  s << "Type: #{opts.fetch(:type)}"
  s << "Tags: #{opts.fetch(:tags)}"
  s << "Summary: #{opts.fetch(:summary)}"
  s << "Published: #{opts.fetch(:published)}"
  s << ""
  s << opts.fetch(:content)
  s.join "\n"
end

def save_post post, path
  filename = post.split("\n").first.downcase.gsub(/ /, '-') + ".md"
  write_file post, path + filename
end

def write_file content, path
  File.open(path, "w:UTF-8"){|o| o.puts content}
end

def random_string length=8
  (1..length).map{('a'..'z').to_a[rand(26)] }.join
end
