require_relative '../../../lib/contraption/catalog'
require 'date'

module Contraption
  describe Catalog do
    context "item storage" do
      before (:each) do
        @items = %w[a b c d e f g]
        @c = Catalog.new @items
      end

      it "stores items" do
        @c.items.should eq @items
      end

      it "stores new items" do
        @c << "P"
        @c.items.should eq(@items << "P")
      end

      it "delegates #each to @items" do
        @c.each.to_a.should eq @items
      end
    end

    context "date grouping" do
      let(:item_1)  { stub(publication_date: Date.new(2012, 2, 1)) }
      let(:item_2)  { stub(publication_date: Date.new(2012, 1, 1)) }
      let(:item_3)  { stub(publication_date: Date.new(2013, 1, 7)) }
      let(:item_4)  { stub(publication_date: Date.new(2013, 1, 8)) }
      let(:catalog) { Catalog.new [item_1, item_2, item_3, item_4] }

      it "groups items by year" do
        catalog.by_year.should eq ({
          Year.new(2012) => [item_1, item_2],
          Year.new(2013) => [item_3, item_4]
        })
      end

      it "groups items by month" do
        catalog.by_month.should eq ({
          Month.new(2012, 2) => [item_1],
          Month.new(2012, 1) => [item_2],
          Month.new(2013, 1) => [item_3, item_4]
        })
      end

      it "groups items by passed block" do
        catalog.by_day.should eq ({
          Day.new(2012, 2, 1) => [item_1],
          Day.new(2012, 1, 1) => [item_2],
          Day.new(2013, 1, 7) => [item_3],
          Day.new(2013, 1, 8) => [item_4]
        })
      end

      context "#most_recent" do
        it "returns the most recently published item" do
          catalog.most_recent.should eq [item_4]
        end

        it "returns the 3 most recently published items" do
          catalog.most_recent(3).should eq [item_4, item_3, item_1]
        end

        it "returns all posts given a negative parameter" do
          catalog.most_recent(-1).should eq [item_4, item_3, item_1, item_2]
        end
      end
    end

    it "includes enumerable" do
      Catalog.included_modules.should include Enumerable
    end
  end
end
