require_relative '../../spec_helper.rb'

module Contraption
  describe Post do
    it "has a body" do
      Post.new.body
    end

    it "has metadata" do
      Post.new.metadata
    end

    context "::build" do
      it "returns a post object from the given string" do
        Post.build("testing").class.should eq Post
      end

      it "has a nonempty title" do
        Post.build("testing").title.should_not eq ""
      end

      it "has a nonempty body" do
        p = Post.build("testing\n\nsome content for the post")
        p.body.should_not eq ""
      end

      it "captures the entire contents of multiline posts" do
        p = Post.build("testing\n\nsome content for the post\n\nsome more content")
        p.body.should include "<p>some content for the post</p>\n\n<p>some more content</p>"
      end

      it "translates markdown to html" do
        p = Post.build("testing\n\n__bold text__")
        p.body.should include "<strong>bold text</strong>"
      end
    end

    context ".publish" do
      it "sets the new date" do
        p = Post.build "\n\n"
        p = p.publish.publication_date.to_s.should eq Time.now.to_s
      end

      it "does not modify the body" do
        p = Post.build "\n\nSome stuff"
        p.publish.body.should include "Some stuff"
      end
    end
  end
end
