require_relative '../../../lib/contraption/repository.rb'

module Contraption
  describe Repository do
    context "validity" do
      before(:each) do
        @source = double()
        @source.stub(exist?: true)
        @source.stub(:cd).and_return("")
      end

      it "raises an error if the structure is invalid" do
        @source.stub(list: %w[drafts pictures])
        expect {r = Repository.new(@source)}.to raise_error
      end
    end

    it "finds the drafts" do
      Repository.any_instance.stub(:validate)
      source = double()
      source.stub(:list).and_return(%w[test.md house.md])
      source.stub(cd: source)
      r = Repository.new(source)
      r.drafts.should eq %w[test.md house.md]
    end

    it "returns a collection of posts" do
      Repository.any_instance.stub(:validate)
      source = double()
      source.stub(:list).and_return(%w[test.md house.md])
      source.stub(:read).with("test.md").and_return("something")
      source.stub(:read).with("house.md").and_return("something else")
      source.stub(cd: source)
      r = Repository.new(source)
      r.posts.should respond_to :each
    end
  end
end
